// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef SERVERWND_H
#define SERVERWND_H

#include <wx/panel.h>                       // Needed for wxPanel

class CServerListCtrl;

class CServerWnd : public wxPanel
{
  DECLARE_DYNAMIC_CLASS(CServerWnd)
    
    CServerWnd() {};

public:
	CServerWnd(wxWindow* pParent);   // standard constructor
	virtual ~CServerWnd();
	void Localize();
	void UpdateServerMetFromURL(wxString strURL);
	void UpdateMyInfo();

// Dialog Data
	enum
        {
            IDD
        };
	CServerListCtrl* serverlistctrl;
protected:
public:
	void OnBnClickedAddserver(wxCommandEvent & evt);
	void OnBnClickedUpdateservermetfromurl(wxCommandEvent & evt);
	void OnBnClickedResetLog(wxCommandEvent & evt);
private:
	DECLARE_EVENT_TABLE()
};

#endif
